# CHANGELOG


## v0.1.2 (2024-12-11)

### Unknown

* Merge branch 'main' of github.com:COMPAS-Surrogate/lnl_computer into main ([`aae1fad`](https://github.com/COMPAS-Surrogate/lnl_computer/commit/aae1fad92253f2236123e50b9b448bb380e0a74a))


## v0.1.1 (2024-12-11)

### Bug Fixes

* fix: correct build requirements in toml (cant include a git+https install) ([`a66af5d`](https://github.com/COMPAS-Surrogate/lnl_computer/commit/a66af5db304920a57f58906322d24d98ddffe4e6))

* fix: correct build requirements in toml (cant include a git+https install) ([`ea43c97`](https://github.com/COMPAS-Surrogate/lnl_computer/commit/ea43c97020701063795b750af550e7c0c3b2e480))

* fix: formatting ([`35d13f7`](https://github.com/COMPAS-Surrogate/lnl_computer/commit/35d13f7c705fb61d191b75a6ac184ec1b57c2e70))

### Chores

* chore(release): 0.1.1 ([`9cb2174`](https://github.com/COMPAS-Surrogate/lnl_computer/commit/9cb217446ddd1b078b21f1664e28ff74a9d735a8))

### Unknown

* Merge branch 'main' of github.com:COMPAS-Surrogate/lnl_computer into main ([`3560ffc`](https://github.com/COMPAS-Surrogate/lnl_computer/commit/3560ffccc2ff08e5bdfd4ddc454c7e7f809f73b0))

* increase LnL error threshold ([`185068c`](https://github.com/COMPAS-Surrogate/lnl_computer/commit/185068c31a56f0a4a30222d3758ad87e989eed3d))

* fix:add badge ([`8ad92da`](https://github.com/COMPAS-Surrogate/lnl_computer/commit/8ad92daa8604f263ecbd6c663a02c53957604e0c))


## v0.1.0 (2024-12-12)

### Unknown

* setup scm versioning ([`66a855d`](https://github.com/COMPAS-Surrogate/lnl_computer/commit/66a855d4e3948c459e3360e56bc7d4be53b32c9d))

* increase min python ([`78e02b7`](https://github.com/COMPAS-Surrogate/lnl_computer/commit/78e02b7b24aaa7c1dfc7105723ccddf4053f5d9e))

* add improved example ([`6cff04c`](https://github.com/COMPAS-Surrogate/lnl_computer/commit/6cff04c1c2868dfe1bf0bff92524c568d3925e2c))

* fixes to duration handling ([`8c30b89`](https://github.com/COMPAS-Surrogate/lnl_computer/commit/8c30b892071af2bca7406f3928f0d7251d073d8f))

* Add some duration args for the analytical checks ([`cc19b81`](https://github.com/COMPAS-Surrogate/lnl_computer/commit/cc19b81401ae799157876ca3f9601509d3652281))

* Add more data filtering for LVK (add option to load specific observing runs) ([`748c4eb`](https://github.com/COMPAS-Surrogate/lnl_computer/commit/748c4ebaf89dedf911ae5b4b0dc0451bb4d0246b))

* repace muz sigma0 --> mu_z sigma_0 to match COMPAS utils ([`f55bb60`](https://github.com/COMPAS-Surrogate/lnl_computer/commit/f55bb6013a3b20a87ef202b22ecef02c07162f40))

* pushing changes ([`88276b8`](https://github.com/COMPAS-Surrogate/lnl_computer/commit/88276b8e75fe541c93f555faf55b4bf9a3f403d8))

* setup LVK observation object ([`7da3d9e`](https://github.com/COMPAS-Surrogate/lnl_computer/commit/7da3d9e13de36e0d20d716c3594fe9f2e2aa4327))

* Merge pull request #1 from COMPAS-Surrogate/lvk_lnl

add LVK lnl ([`2960321`](https://github.com/COMPAS-Surrogate/lnl_computer/commit/2960321d8ee07d749c99d3b13c0b9aba34098ad3))

* add LVK lnl ([`88cc625`](https://github.com/COMPAS-Surrogate/lnl_computer/commit/88cc62592bd8f4cf04b1af72ba07d4a466def950))

* add ogc4 tempalte ([`b185c64`](https://github.com/COMPAS-Surrogate/lnl_computer/commit/b185c64126d2597fd51c2119f4c5502d12f9093d))

* change logger ([`d53b3da`](https://github.com/COMPAS-Surrogate/lnl_computer/commit/d53b3da8240d9e8b599348ac8916da661c368b20))

* add prior-acquisiton ([`495ef19`](https://github.com/COMPAS-Surrogate/lnl_computer/commit/495ef19901fead92916398a9dec9bfa219e6fe6c))

* add correctt labeo ([`2d11716`](https://github.com/COMPAS-Surrogate/lnl_computer/commit/2d11716f9b420424114ddd6dfadc82b3d88e3d89))

* add file log ([`d3f56c2`](https://github.com/COMPAS-Surrogate/lnl_computer/commit/d3f56c2d4cefdacc3f7cd2f86190055c5cec928b))

* add mock data lnnl test ([`ab94f68`](https://github.com/COMPAS-Surrogate/lnl_computer/commit/ab94f681eadb1209130593e88115264afe8f74f1))

* save lnl without unc in mock-obs ([`3ab1b03`](https://github.com/COMPAS-Surrogate/lnl_computer/commit/3ab1b0362224f4fbead3ebd5a6a6bb5b93ac11de))

* add plot saving ([`7b844c1`](https://github.com/COMPAS-Surrogate/lnl_computer/commit/7b844c1415a71319a83aeb27783bd25bee9ff21f))

* add data ([`22004fc`](https://github.com/COMPAS-Surrogate/lnl_computer/commit/22004fc5f829bac40a3239173154e657a6a1d436))

* Merge branch 'main' of github.com:COMPAS-Surrogate/lnl_computer ([`bc5f47d`](https://github.com/COMPAS-Surrogate/lnl_computer/commit/bc5f47d2f4dae54b0720e74187b767ca86dd925e))

* update caching ([`60eb696`](https://github.com/COMPAS-Surrogate/lnl_computer/commit/60eb696f48c9e5f0710fb79f5d534265524e7464))

* make mock-values reproducible ([`ae9774d`](https://github.com/COMPAS-Surrogate/lnl_computer/commit/ae9774d51dac14b9e6853bf3ba48e07cec262b2f))

* add colorlog ([`9ac61e9`](https://github.com/COMPAS-Surrogate/lnl_computer/commit/9ac61e9fc20a4f1577081f7dbd39129570039167))

* add test to ensure the LnL value is the same ([`caf8a82`](https://github.com/COMPAS-Surrogate/lnl_computer/commit/caf8a8211d052b163fae7117010e4aee1a837df6))

* rework mock dataset ([`99fd304`](https://github.com/COMPAS-Surrogate/lnl_computer/commit/99fd30412b261d388b37afb0ab01557ed3090c08))

* fix logger ([`b76962c`](https://github.com/COMPAS-Surrogate/lnl_computer/commit/b76962cfb0f411b7901976c4da160178890c564f))

* add more info for mock dataset ([`a92119e`](https://github.com/COMPAS-Surrogate/lnl_computer/commit/a92119e05bac97f2d68384adeaaade670f348ce6))

* run precommits ([`5d07ac4`](https://github.com/COMPAS-Surrogate/lnl_computer/commit/5d07ac4e36a572fa5232d35a7494d050456ad303))

* allow both mu_z muz sigma0 sigma_0 ([`82615b9`](https://github.com/COMPAS-Surrogate/lnl_computer/commit/82615b9c93ad6f741594162189a8c1bfda19df4f))

* fix param name ([`eb2403f`](https://github.com/COMPAS-Surrogate/lnl_computer/commit/eb2403f235dc1207aef6630f9cfb3dd63285f5ac))

* Merge branch 'main' of github.com:COMPAS-Surrogate/lnl_computer into main ([`08c07c7`](https://github.com/COMPAS-Surrogate/lnl_computer/commit/08c07c737fb84d95a092fc4c4ea88663375167a0))

* add mock observations ([`1473423`](https://github.com/COMPAS-Surrogate/lnl_computer/commit/1473423a969332d7349d3226232b8dff799ee416))

* add mock lnl duration ([`46484cb`](https://github.com/COMPAS-Surrogate/lnl_computer/commit/46484cbf003c7ed5504f019f1cb1bc590bf48318))

* add lnl nan fix ([`fa08764`](https://github.com/COMPAS-Surrogate/lnl_computer/commit/fa08764a641327bee89be7897c304d94e6c9c256))

* add mock data ([`a7d35cd`](https://github.com/COMPAS-Surrogate/lnl_computer/commit/a7d35cdbe4a9690b098e3decf95fa6a1c3980a31))

* add config ([`21e5b18`](https://github.com/COMPAS-Surrogate/lnl_computer/commit/21e5b18683c6527e12a8b90a36cb002d3de8ede6))

* fix tests ([`ecacda1`](https://github.com/COMPAS-Surrogate/lnl_computer/commit/ecacda12a0fc849346b01f0ad949f67650bce8c6))

* add tests ([`b8218c6`](https://github.com/COMPAS-Surrogate/lnl_computer/commit/b8218c67e046adebc135761a21cb411174280249))

* remove dependancies ([`57c2454`](https://github.com/COMPAS-Surrogate/lnl_computer/commit/57c24547023d51509a688465a50170dcd40ed68d))

* add true JSON ([`09facf9`](https://github.com/COMPAS-Surrogate/lnl_computer/commit/09facf9c814b8e75e9908660e7f2ddfd2e2ca19f))

* log params ([`ecfaab9`](https://github.com/COMPAS-Surrogate/lnl_computer/commit/ecfaab9ceedd3a6d858267de38e859809a44f328))

* add testing scriots ([`43e9dad`](https://github.com/COMPAS-Surrogate/lnl_computer/commit/43e9dad7c7674c81b250f22c7046397ea012a901))

* refactor mocked-data ([`272ffc0`](https://github.com/COMPAS-Surrogate/lnl_computer/commit/272ffc05b75b39b60d023cb2aca390f283d64393))

* formatting fix ([`912d871`](https://github.com/COMPAS-Surrogate/lnl_computer/commit/912d8719af57dc475f32236f183f4b890131727f))

* remove old HDF5 loader with index of matrix in large HDF5 file of several matrices ([`44c4e91`](https://github.com/COMPAS-Surrogate/lnl_computer/commit/44c4e91cef64814fdce5cbf1c1454563d919afa6))

* add tests for star-formation params sampler ([`4578cda`](https://github.com/COMPAS-Surrogate/lnl_computer/commit/4578cda59af2f996a269f08e0032116779426c28))

* fix workflow ([`8b14648`](https://github.com/COMPAS-Surrogate/lnl_computer/commit/8b1464809e69565e8bdf0c5836232e42e782628a))

* t push origin main
Merge branch 'main' of github.com:COMPAS-Surrogate/lnl_computer into main ([`233be1b`](https://github.com/COMPAS-Surrogate/lnl_computer/commit/233be1ba7fd7e0ed687cbdbd9e17f15ad6b21f46))

* Update README.md ([`2e45a77`](https://github.com/COMPAS-Surrogate/lnl_computer/commit/2e45a77c630211c4dd498812da7b03438e019cd5))

* fix workflow ([`8563b93`](https://github.com/COMPAS-Surrogate/lnl_computer/commit/8563b93684741b892193433ef300cb1ab1552468))

* fix pathing issue for combine LnL ([`1628ff7`](https://github.com/COMPAS-Surrogate/lnl_computer/commit/1628ff7449d7c7409be8f6be823fa10ba6d792b0))

* black vrsion change ([`1f26cf4`](https://github.com/COMPAS-Surrogate/lnl_computer/commit/1f26cf403697321aebb71839913e05fc33640de0))

* add MC-z save-fname changes ([`f71faa2`](https://github.com/COMPAS-Surrogate/lnl_computer/commit/f71faa2256ede6861e7b15c0d94a9b9c0e1744a9))

* allow custom fnames ([`90a10c1`](https://github.com/COMPAS-Surrogate/lnl_computer/commit/90a10c1f24af4d243166c35e590f44c9ba73e719))

* refactoring ([`efdef79`](https://github.com/COMPAS-Surrogate/lnl_computer/commit/efdef79d814eb2b9d710f4c1411d026b684b5bd2))

* refactor ([`ac4dba7`](https://github.com/COMPAS-Surrogate/lnl_computer/commit/ac4dba7b4ae3b0257570760e2757d32d69b37a92))

* cleanup ([`0f66736`](https://github.com/COMPAS-Surrogate/lnl_computer/commit/0f66736ad89b6bafc825d47b346d22c101862fba))

* add data generators ([`8abcc17`](https://github.com/COMPAS-Surrogate/lnl_computer/commit/8abcc1733dd9ec37dc9ed4fea958d49790627c87))

* add LnL data gen scripts ([`cfe01e1`](https://github.com/COMPAS-Surrogate/lnl_computer/commit/cfe01e12892cb1a8a1435bcac2571c72231e727c))

* init ([`d14507c`](https://github.com/COMPAS-Surrogate/lnl_computer/commit/d14507cc4c870cf101ef02d99b64ee99df73ba65))

* init proj ([`282a8c2`](https://github.com/COMPAS-Surrogate/lnl_computer/commit/282a8c2ff297affabe7ee863598a325c104b9254))

* Initial commit ([`5f93a66`](https://github.com/COMPAS-Surrogate/lnl_computer/commit/5f93a66d4f0788f77f4c5917791b4cb0ac26e62d))
